@@ -1,3 +1,6 @@
+#![deny(clippy::all)]
+#![allow(unstable_name_collisions)]
+
 pub use self::{
     bundler::{Bundle, BundleKind, Bundler, Config, ModuleType},
     hook::{Hook, ModuleRecord},
